package com.ibm.tools.attach;
/*
 * Licensed Materials - Property of IBM,
 *     Copyright IBM Corp. 2009, 2010  All Rights Reserved
 */
import java.security.BasicPermission;

/**
 * Checked when a VM tries to attach to a VM, if a SecurityManager is set.
 *
 * This class is analogous to and intended to be compatible with com.sun.tools.attach.AttachPermission.
 *
 * @see "http://w3.hursley.ibm.com/java/docs/java7/jdk/api/attach/spec/com/sun/tools/attach/AttachPermission.html"
 *
 */
public final class AttachPermission extends BasicPermission {

	/**
	 *
	 */
	private static final long serialVersionUID = -2631846707883884525L;
	/**
	 * @param name Name of the permission
	 * @throw IllegalArgumentException If name is not  "createAttachProvider"  or "attachVirtualMachine".
	 * @note Public API, signature compatible with com.sun.tools.attach.spi.AttachProvider.
	 */
	public AttachPermission(String name) {
		super(name);
		checkName(name);
	}

	/**
	 * @param name Name of the permission
	 * @param actions not used, must be null or an empty string
	 * @throw IllegalArgumentException If name is not  "createAttachProvider"  or "attachVirtualMachine".
	 * @note Public API, signature compatible with com.sun.tools.attach.spi.AttachProvider.
	 */
	public AttachPermission(String name, String actions) {
		super(name, actions);

		checkName(name);

		/* Ensure that actions is null or an empty string */
		if (!((null == actions) || (actions.length() == 0))) {
			throw new IllegalArgumentException();
		}
	}

	/**
	 * Validate that the name is one of the recognized permissions (e.g. "createAttachProvider" or "attachVirtualMachine")
	 * @param name The name to test.
	 */
	private void checkName(String name) {
		if (!name.equals("attachVirtualMachine") && !name.equals("createAttachProvider")) {
			throw new IllegalArgumentException("AttachPermission " + name); //$NON-NLS-1$
		}
	}

	@Override
	public void checkGuard(Object object) throws SecurityException {
		return;
	}
}
